// Copyright (C) 2021 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
// Qt-Security score:significant reason:default


#ifndef QTSHADERTOOLSGLOBAL_H
#define QTSHADERTOOLSGLOBAL_H

#include <QtCore/qglobal.h>
#include <QtShaderTools/qtshadertoolsexports.h>

#ifdef Q_QDOC
#define Q_SHADERTOOLS_EXPORT
#endif

#endif
